
#include "nordic_common.h"
#include "boards.h"
#include "nrf_delay.h"

#include "hx711.h"


const uint8_t PD_SCK1 = LOADCELL1_CLK_PIN;
const uint8_t DOUT1 = LOADCELL1_DATA_PIN;
uint8_t GAIN;
long OFFSET;
#define LOW 0
#define HIGH 1

void HX711_begin(uint8_t gain) 
{
	OFFSET = 0;

	nrf_gpio_cfg_output(PD_SCK1);
	nrf_gpio_cfg_input(DOUT1,NRF_GPIO_PIN_PULLUP);
	nrf_gpio_pin_set(PD_SCK1);

	nrf_delay_us(70);
	
	HX711_set_gain(gain);
	nrf_gpio_pin_set(PD_SCK1);

}

uint8_t HX711_is_ready_load1() 
{
	if(nrf_gpio_pin_read(DOUT1) == 0)
		return 1;
	else
		return 0;
}

void HX711_set_gain(uint8_t gain) 
{
	switch (gain) {
		case 128:		// channel A, gain factor 128
			GAIN = 1;
			break;
		case 64:		// channel A, gain factor 64
			GAIN = 3;
			break;
		case 32:		// channel B, gain factor 32
			GAIN = 2;
			break;
	}

	nrf_gpio_pin_write(PD_SCK1, LOW);
	HX711_read_load1();
}

uint8_t shiftIn_load1()
{
	uint8_t data;
	uint8_t bit;
	data = 0;
	// set the channel and the gain factor for the next reading using the clock pin
	for (unsigned int i = 0; i < 8; i++) 
	{
		nrf_delay_us(2);
		nrf_gpio_pin_write(PD_SCK1, HIGH);
		nrf_delay_us(2);
		nrf_gpio_pin_write(PD_SCK1, LOW);
		data = data << 1;
		bit = nrf_gpio_pin_read(DOUT1);
		data = data | bit;
	}
	return data;
}

uint32_t HX711_read_load1() 
{
	volatile uint8_t pinval;
	pinval = nrf_gpio_pin_out_read(PD_SCK1);
	if(pinval == 1)
		nrf_gpio_pin_clear(PD_SCK1);
	// wait for the chip to become ready
	while (!HX711_is_ready_load1()) {
	}

	uint32_t value = 0;
	uint8_t data[3] = { 0 };
	uint8_t filler = 0x00;

	
	// pulse the clock pin 24 times to read the data
	data[2] = shiftIn_load1();
	data[1] = shiftIn_load1();
	data[0] = shiftIn_load1();

	
	// set the channel and the gain factor for the next reading using the clock pin
	for (unsigned int i = 0; i < GAIN; i++) {
		nrf_delay_us(2);
		nrf_gpio_pin_write(PD_SCK1, HIGH);
		nrf_delay_us(2);
		nrf_gpio_pin_write(PD_SCK1, LOW);
	}

	// Replicate the most significant bit to pad out a 32-bit signed integer
	if (data[2] & 0x80) {
		filler = 0xFF;
	} else {
		filler = 0x00;
	}

	// Construct a 32-bit signed integer
	value = ( (uint32_t)(filler) << 24
			| (uint32_t)(data[2]) << 16
			| (uint32_t)(data[1]) << 8
			| (uint32_t)(data[0]) );

	return (value);
}

void HX711_set_offset(long offset) 
{
	OFFSET = offset;
}

long HX711_get_offset() 
{
	return OFFSET;
}

void HX711_power_down() 
{
	nrf_gpio_pin_write(PD_SCK1, HIGH);
	nrf_delay_us(60);
}

void HX711_power_up() 
{
	nrf_gpio_pin_write(PD_SCK1, LOW);
}

